@@ -46,7 +46,10 @@ struct DownloadConfig
     bool bRemoteXML;
     bool bSaveChangelogs;
     bool bSaveSerials;
+    bool bSaveGameDetailsJson;
+    bool bSaveProductJson;
     bool bSaveLogo;
+    bool bSaveIcon;
     bool bAutomaticXMLCreation;
     bool bFreeSpaceCheck;
 
@@ -249,8 +252,10 @@ class Config
         bool bPlatformDetection;
 #ifdef USE_QT_GUI_LOGIN
         bool bEnableLoginGUI;
+        bool bForceGUILogin;
 #endif
         bool bUseFastCheck;
+        bool bTrustAPIForExtras;
 
         // Cache
         bool bUseCache;
