@@ -61,6 +61,9 @@ struct xferInfo
     Timer timer;
     std::deque< std::pair<time_t, uintmax_t> > TimeAndSize;
     curl_off_t offset;
+    bool isChunk = false;
+    curl_off_t chunk_file_total = 0;
+    curl_off_t chunk_file_offset = 0;
 };
 
 typedef struct
@@ -148,6 +151,7 @@ class Downloader
         static std::string getSerialsFromJSON(const Json::Value& json);
         void saveSerials(const std::string& serials, const std::string& filepath);
         static std::string getChangelogFromJSON(const Json::Value& json);
+        void saveJsonFile(const std::string& json, const std::string& filepath);
         void saveChangelog(const std::string& changelog, const std::string& filepath);
         static void processDownloadQueue(Config conf, const unsigned int& tid);
         static void processCloudSaveDownloadQueue(Config conf, const unsigned int& tid);
