@@ -55,7 +55,7 @@ namespace GlobalConstants
         { LANGUAGE_FR, "fr", "French",     "fr|fra|fre|french|fr[_-]FR"     },
         { LANGUAGE_PL, "pl", "Polish",     "pl|pol|polish|pl[_-]PL"         },
         { LANGUAGE_RU, "ru", "Russian",    "ru|rus|russian|ru[_-]RU"        },
-        { LANGUAGE_CN, "cn", "Chinese",    "cn|zh|zho|chi|chinese|zh[_-]CN" },
+        { LANGUAGE_CN, "cn", "Chinese",    "cn|zh|zho|chi|chinese|zh[_-](CN|Hans)" },
         { LANGUAGE_CZ, "cz", "Czech",      "cz|cs|ces|cze|czech|cs[_-]CZ"   },
         { LANGUAGE_ES, "es", "Spanish",    "es|spa|spanish|es[_-]ES"        },
         { LANGUAGE_HU, "hu", "Hungarian",  "hu|hun|hungarian|hu[_-]HU"      },
@@ -123,6 +123,7 @@ namespace GlobalConstants
     const unsigned int LIST_FORMAT_DETAILS_JSON    = 1 << 2;
     const unsigned int LIST_FORMAT_TAGS            = 1 << 3;
     const unsigned int LIST_FORMAT_TRANSFORMATIONS = 1 << 4;
+    const unsigned int LIST_FORMAT_USERDATA        = 1 << 5;
 
     const std::vector<optionsStruct> LIST_FORMAT =
     {
@@ -130,7 +131,8 @@ namespace GlobalConstants
         { LIST_FORMAT_DETAILS_TEXT, "details", "Details", "d|details" },
         { LIST_FORMAT_DETAILS_JSON, "json",    "JSON",    "j|json"    },
         { LIST_FORMAT_TAGS,         "tags",    "Tags",    "t|tags"    },
-        { LIST_FORMAT_TRANSFORMATIONS, "transform", "Transformations", "tr|transform|transformations" }
+        { LIST_FORMAT_TRANSFORMATIONS, "transform", "Transformations", "tr|transform|transformations" },
+        { LIST_FORMAT_USERDATA,     "userdata", "User data", "ud|userdata" }
     };
 
     const unsigned int GFTYPE_BASE_INSTALLER = 1 << 0;
